#!perl

use Test::More tests => 1;

BEGIN {
	use_ok( 'Slackware::Slackget::Network::Connection::DEBUG' );
}

diag( "Testing Slackware::Slackget::Network::Connection::DEBUG $Slackware::Slackget::Network::Connection::DEBUG::VERSION, Perl $], $^X" );
